==> open-xchange-documents-backend_7.4.1.orig.tar.bz2: open-xchange-documents-backend-7.4.1/com.openexchange.office.ooxml/src/main/java/org/docx4j/dml/chart/STLegendPos.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.chart;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_LegendPos.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_LegendPos">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="b"/>
 *     &lt;enumeration value="tr"/>
 *     &lt;enumeration value="l"/>
 *     &lt;enumeration value="r"/>
 *     &lt;enumeration value="t"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_LegendPos")
@XmlEnum
public enum STLegendPos {


    /**
     * Bottom
     * 
     */
    @XmlEnumValue("b")
    B("b"),

    /**
     * Top Right
     * 
     */
    @XmlEnumValue("tr")
    TR("tr"),

    /**
     * Left
     * 
     */
    @XmlEnumValue("l")
    L("l"),

    /**
     * Right
     * 
     */
    @XmlEnumValue("r")
    R("r"),

    /**
     * Top
     * 
     */
    @XmlEnumValue("t")
    T("t");
    private final String value;

    STLegendPos(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STLegendPos fromValue(String v) {
        for (STLegendPos c: STLegendPos.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> open-xchange-documents-backend_7.4.2.orig.tar.bz2: open-xchange-documents-backend-7.4.2/com.openexchange.office.ooxml/src/main/java/org/docx4j/dml/chart/STLegendPos.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.chart;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_LegendPos.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_LegendPos">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="b"/>
 *     &lt;enumeration value="tr"/>
 *     &lt;enumeration value="l"/>
 *     &lt;enumeration value="r"/>
 *     &lt;enumeration value="t"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_LegendPos")
@XmlEnum
public enum STLegendPos {


    /**
     * Bottom
     * 
     */
    @XmlEnumValue("b")
    B("b", "bottom"),

    /**
     * Top Right
     * 
     */
    @XmlEnumValue("tr")
    TR("tr", "topright"),

    /**
     * Left
     * 
     */
    @XmlEnumValue("l")
    L("l", "left"),

    /**
     * Right
     * 
     */
    @XmlEnumValue("r")
    R("r", "right"),

    /**
     * Top
     * 
     */
    @XmlEnumValue("t")
    T("t", "top");
    private final String value;
    private final String realName;

    STLegendPos(String v, String realName) {
        value = v;
        this.realName = realName;
    }

    public String value() {
        return value;
    }

    public static STLegendPos fromValue(String v) {
        for (STLegendPos c: STLegendPos.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

    public String getRealName() {
        return realName;
    }

}
